Change Log
==========

6.0.0
-----
- Molo 6 compatibility

5.0.8
-----
- Molo plugin templates refactor and cleanup


5.0.7
-----
- Bug Fix: filter content by site in the template tags


5.0.6
-----
- Bug Fix: change the parent page for yourtips tip section index page when copy

5.0.5
-----
- Bug fix: Date range filter on tip and entry wagtail admin.

5.0.4
-----
- Bug fix: Only activate "YourTips" with published YourTip pages.
- Change: Verification message on tip submission form show word count now.
- Change: Download CSV on converted tip articles to only download relevant information.

5.0.3
-----
- Bug fix popular tip ListView
- New feature Download CSV

5.0.1
-----
- Update travis password

5.0.0
-----
- Initial release
